@@ -13,6 +13,8 @@
 """
 from typing import Optional
 
+from setproctitle import setproctitle
+
 from peek_platform.file_config.PeekFileConfigHttpServerMixin import (
     PeekFileConfigHttpMixin,
 )
@@ -49,6 +51,7 @@ def setupPlatform():
     from peek_platform import PeekPlatformConfig
 
     PeekPlatformConfig.componentName = peekFieldName
+    setproctitle(PeekPlatformConfig.componentName)
 
     # Tell the platform classes about our instance of the PluginSwInstallManager
     from peek_field_service.sw_install.PluginSwInstallManager import (
